@@ -1,11 +1,11 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Rope::Object;
-my (%META);
-our (%PRO);
+my (%META, %PRO);
+our @ISA;
 BEGIN {
 	%PRO = (
 		keyword => sub {
@@ -134,6 +134,8 @@ BEGIN {
 							$merge->{properties}->{$_} = $initial->{properties}->{$_};
 						}
 					}
+					my $isa = '@' . $caller . '::ISA';
+					eval "push $isa, '$extend'";
 					$META{$caller} = $merge;
 				}
 			}
@@ -174,17 +176,18 @@ sub import {
 		for qw/function property prototyped extends new/;
 }
 
+
 1;
 
 __END__
 
 =head1 NAME
 
-Rope - The great new Rope!
+Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
@@ -270,10 +273,8 @@ L<https://metacpan.org/release/Rope>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 LICENSE AND COPYRIGHT
 
 This software is Copyright (c) 2023 by LNATION.
@@ -282,7 +283,6 @@ This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
-
 =cut
 
 1; # End of Rope
