@@ -62,7 +62,7 @@ Rope::Type - Rope with Type::Tiny
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
@@ -76,9 +76,7 @@ Version 0.03
 	int loops => 1;
 	int hitches => 10;
 	int bends => (
-		type => int,
 		value => 10,
-		writeable => 0,
 		configurable => 1,
 		enumerable => 1,
 	);
